@@ -141,9 +141,10 @@ void DatabaseSettingsWidget::setupMainArea()
     d->dbBinariesWidget               = new DBinarySearch(binaryBox);
     d->dbBinariesWidget->header()->setSectionHidden(2, true);
 
-    d->dbBinariesWidget->addBinary(d->mysqlInitBin);
+    d->dbBinariesWidget->addBinary(d->mysqlServerBin);
     d->dbBinariesWidget->addBinary(d->mysqlAdminBin);
-    d->dbBinariesWidget->addBinary(d->mysqlServBin);
+    d->dbBinariesWidget->addBinary(d->mysqlUpgradeBin);
+    d->dbBinariesWidget->addBinary(d->mysqlInitBin);
 
 #ifdef Q_OS_LINUX
 
@@ -305,6 +306,9 @@ void DatabaseSettingsWidget::setupMainArea()
                            "<p>Enter SQL code to Mysql prompt in order to init digiKam databases with grant privileges (see behind)</p>"
                            "<p>...</p>"
                            "<p>quit</p>"
+                           "<p>NOTE: If you have problems with a MySQL server on Ubuntu based Linux system, "
+                           "use the addition command in the mysql prompt to be able to create MySQL triggers.<br>"
+                           "SET GLOBAL log_bin_trust_function_creators=1;</p>"
                            "<p>NOTE: If you have an enormous collection, you should start MySQL server with "
                            "mysql --max_allowed_packet=128M OR in my.ini or ~/.my.cnf, change the settings</p>"));
 
@@ -716,9 +720,10 @@ void DatabaseSettingsWidget::setParametersFromSettings(const ApplicationSettings
     {
         d->dbPathEdit->setFileDlgPath(d->orgPrms.internalServerPath());
         d->dbType->setCurrentIndex(d->dbTypeMap[MysqlInternal]);
+        d->mysqlUpgradeBin.setup(QFileInfo(d->orgPrms.internalServerMysqlUpgradeCmd).absoluteFilePath());
+        d->mysqlServerBin.setup(QFileInfo(d->orgPrms.internalServerMysqlServerCmd).absoluteFilePath());
         d->mysqlAdminBin.setup(QFileInfo(d->orgPrms.internalServerMysqlAdminCmd).absoluteFilePath());
         d->mysqlInitBin.setup(QFileInfo(d->orgPrms.internalServerMysqlInitCmd).absoluteFilePath());
-        d->mysqlServBin.setup(QFileInfo(d->orgPrms.internalServerMysqlServCmd).absoluteFilePath());
         d->dbBinariesWidget->allBinariesFound();
         d->walModeCheck->setChecked(false);
         slotResetMysqlServerDBNames();
@@ -763,9 +768,10 @@ DbEngineParameters DatabaseSettingsWidget::getDbEngineParameters() const
         {
             prm = DbEngineParameters::defaultParameters(databaseBackend());
             prm.setInternalServerPath(databasePath());
-            prm.internalServerMysqlAdminCmd = d->mysqlAdminBin.path();
-            prm.internalServerMysqlInitCmd  = d->mysqlInitBin.path();
-            prm.internalServerMysqlServCmd  = d->mysqlServBin.path();
+            prm.internalServerMysqlUpgradeCmd = d->mysqlUpgradeBin.path();
+            prm.internalServerMysqlServerCmd  = d->mysqlServerBin.path();
+            prm.internalServerMysqlAdminCmd   = d->mysqlAdminBin.path();
+            prm.internalServerMysqlInitCmd    = d->mysqlInitBin.path();
             break;
         }
 
