@@ -10,18 +10,9 @@
  *               Face Recognition algorithm. It is adapted from recognize.cpp
  *               developed by Aditya Bhatt.
  *
- * Copyright (C) 2019 by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
+ * SPDX-FileCopyrightText: 2019 by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -66,7 +57,7 @@ QList<QImage> toImages(const QStringList& paths)
 {
     QList<QImage> images;
 
-    foreach (const QString& path, paths)
+    Q_FOREACH (const QString& path, paths)
     {
         images << QImage(path);
     }
@@ -169,7 +160,7 @@ QList<QImage*> retrieveFaces(const QList<QImage>& images, const QList<QRectF>& r
     QList<QImage*> faces;
     unsigned index = 0;
 
-    foreach (const QRectF& rect, rects)
+    Q_FOREACH (const QRectF& rect, rects)
     {
         DImg temp(images.at(index));
         QImage* croppedFace = new QImage();
@@ -284,9 +275,9 @@ int main(int argc, char* argv[])
 
     for (unsigned i = 1 ; i <= nbOfIdentities ; ++i)
     {
-        QMap<QString, QString> attributes;
-        attributes[QLatin1String("name")] = QString::number(i);
-        idMap[i]                          = recognizer.addIdentityDebug(attributes);
+        QMultiMap<QString, QString> attributes;
+        attributes.insert(QLatin1String("name"), QString::number(i));
+        idMap[i] = recognizer.addIdentityDebug(attributes);
     }
 
     // Init FaceDetector used for detecting faces and bounding box
@@ -330,7 +321,7 @@ int main(int argc, char* argv[])
 
         qCDebug(DIGIKAM_TESTS_LOG) << "Result for " << it.value().first() << " is identity " << results.first().id();
 
-        foreach (const Identity& foundId, results)
+        Q_FOREACH (const Identity& foundId, results)
         {
             if (foundId.isNull())
             {
@@ -369,7 +360,7 @@ int main(int argc, char* argv[])
         QList<QImage> rawImages = toImages(imagePaths);
         qCDebug(DIGIKAM_TESTS_LOG) << "Training directory " << it.key();
 
-        foreach (const QImage& image, rawImages)
+        Q_FOREACH (const QImage& image, rawImages)
         {
             QString imagePath = imagePaths.takeFirst();
 
@@ -416,7 +407,7 @@ int main(int argc, char* argv[])
         QList<QImage> detectedFaces;
         QList<QRectF> bboxes;
 
-        foreach (const QImage& image, rawImages)
+        Q_FOREACH (const QImage& image, rawImages)
         {
             QString imagePath = imagePaths.takeFirst();
 
@@ -454,7 +445,7 @@ int main(int argc, char* argv[])
 
         // qCDebug(DIGIKAM_TESTS_LOG) << "Result for " << it.value().first() << " is identity " << results.first().id();
 
-        foreach (const Identity& foundId, results)
+        Q_FOREACH (const Identity& foundId, results)
         {
             QString imagePath = imagePaths.takeFirst();
 
@@ -483,7 +474,7 @@ int main(int argc, char* argv[])
              << " (" << float(nbUndetectedTrainedFaces) / (totalTrained + nbUndetectedTrainedFaces) * 100 << "%)"
              << " faces cannot be detected for training";
 
-    foreach (const QString& path, undetectedTrainedFaces)
+    Q_FOREACH (const QString& path, undetectedTrainedFaces)
     {
         qCDebug(DIGIKAM_TESTS_LOG) << path;
     }
@@ -500,7 +491,7 @@ int main(int argc, char* argv[])
              << " (" << float(nbUndetectedTestedFaces) / (totalRecognized + nbUndetectedTestedFaces) * 100 << "%)"
              << " faces cannot be detected for testing";
 
-    foreach (const QString& path, undetectedTestedFaces)
+    Q_FOREACH (const QString& path, undetectedTestedFaces)
     {
         qCDebug(DIGIKAM_TESTS_LOG) << path;
     }
@@ -519,7 +510,7 @@ int main(int argc, char* argv[])
 
     qCDebug(DIGIKAM_TESTS_LOG) << "\nFalse positive faces";
 
-    foreach (const QString& path, falsePositiveFaces)
+    Q_FOREACH (const QString& path, falsePositiveFaces)
     {
         qCDebug(DIGIKAM_TESTS_LOG) << path;
     }
