@@ -7,7 +7,7 @@
  * Description : digiKam setup dialog.
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -48,7 +48,7 @@
 #include "dxmlguiwindow.h"
 #include "onlineversiondlg.h"
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 #   include "setupvideo.h"
 #endif
 
@@ -64,7 +64,13 @@ public:
         page_collections        (nullptr),
         page_albumView          (nullptr),
         page_tooltip            (nullptr),
+
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+
         page_video              (nullptr),
+
+#endif
+
         page_metadata           (nullptr),
         page_template           (nullptr),
         page_lighttable         (nullptr),
@@ -78,9 +84,13 @@ public:
         collectionsPage         (nullptr),
         albumViewPage           (nullptr),
         tooltipPage             (nullptr),
-#ifdef HAVE_MEDIAPLAYER
+
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+
         videoPage               (nullptr),
+
 #endif
+
         metadataPage            (nullptr),
         templatePage            (nullptr),
         lighttablePage          (nullptr),
@@ -97,7 +107,13 @@ public:
     DConfigDlgWdgItem*       page_collections;
     DConfigDlgWdgItem*       page_albumView;
     DConfigDlgWdgItem*       page_tooltip;
+
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+
     DConfigDlgWdgItem*       page_video;
+
+#endif
+
     DConfigDlgWdgItem*       page_metadata;
     DConfigDlgWdgItem*       page_template;
     DConfigDlgWdgItem*       page_lighttable;
@@ -113,7 +129,7 @@ public:
     SetupAlbumView*          albumViewPage;
     SetupToolTip*            tooltipPage;
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
     SetupVideo*              videoPage;
 
@@ -169,7 +185,7 @@ Setup::Setup(QWidget* const parent)
     d->page_tooltip->setHeader(i18nc("@title", "Items Tool-Tip Settings\nCustomize information in item tool-tips"));
     d->page_tooltip->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
     d->videoPage  = new SetupVideo();
     d->page_video = addPage(d->videoPage, i18nc("@title: settings section", "Video"));
@@ -269,7 +285,13 @@ Setup::~Setup()
     group.writeEntry(QLatin1String("Setup Page"),      (int)activePageIndex());
     group.writeEntry(QLatin1String("Albumview Tab"),   (int)d->albumViewPage->activeTab());
     group.writeEntry(QLatin1String("ToolTip Tab"),     (int)d->tooltipPage->activeTab());
+
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+
     group.writeEntry(QLatin1String("Video Tab"),       (int)d->videoPage->activeTab());
+
+#endif
+
     group.writeEntry(QLatin1String("Metadata Tab"),    (int)d->metadataPage->activeTab());
     group.writeEntry(QLatin1String("Metadata SubTab"), (int)d->metadataPage->activeSubTab());
     group.writeEntry(QLatin1String("Editor Tab"),      (int)d->editorPage->activeTab());
@@ -526,7 +548,7 @@ void Setup::slotOkClicked()
     d->albumViewPage->applySettings();
     d->tooltipPage->applySettings();
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
     d->videoPage->applySettings();
 
@@ -557,7 +579,7 @@ void Setup::slotOkClicked()
 void Setup::slotCancelClicked()
 {
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
     d->videoPage->cancel();
 
@@ -577,7 +599,13 @@ void Setup::showPage(Setup::Page page)
         item = d->pageItem((Page)group.readEntry(QLatin1String("Setup Page"), (int)CollectionsPage));
         d->albumViewPage->setActiveTab((SetupAlbumView::AlbumTab)group.readEntry(QLatin1String("AlbumView Tab"), (int)SetupAlbumView::IconView));
         d->tooltipPage->setActiveTab((SetupToolTip::ToolTipTab)group.readEntry(QLatin1String("ToolTip Tab"), (int)SetupToolTip::IconItems));
+
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
+
         d->videoPage->setActiveTab((SetupVideo::VideoTab)group.readEntry(QLatin1String("Video Tab"), (int)SetupVideo::Decoder));
+
+#endif
+
         d->metadataPage->setActiveTab((SetupMetadata::MetadataTab)group.readEntry(QLatin1String("Metadata Tab"), (int)SetupMetadata::Behavior));
         d->metadataPage->setActiveSubTab((SetupMetadata::MetadataSubTab)group.readEntry(QLatin1String("Metadata SubTab"), (int)SetupMetadata::ExifViewer));
         d->editorPage->setActiveTab((SetupEditor::EditorTab)group.readEntry(QLatin1String("Editor Tab"), (int)SetupEditor::EditorWindow));
@@ -618,7 +646,7 @@ Setup::Page Setup::activePageIndex() const
         return ToolTipPage;
     }
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
     if (cur == d->page_video)
     {
@@ -680,53 +708,83 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
     switch (page)
     {
         case Setup::DatabasePage:
+        {
             return page_database;
+        }
 
         case Setup::CollectionsPage:
+        {
             return page_collections;
+        }
 
         case Setup::AlbumViewPage:
+        {
             return page_albumView;
+        }
 
         case Setup::ToolTipPage:
+        {
             return page_tooltip;
+        }
 
-#ifdef HAVE_MEDIAPLAYER
+#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
 
         case Setup::VideoPage:
+        {
             return page_video;
+        }
 
 #endif
 
         case Setup::MetadataPage:
+        {
             return page_metadata;
+        }
 
         case Setup::TemplatePage:
+        {
             return page_template;
+        }
 
         case Setup::LightTablePage:
+        {
             return page_lighttable;
+        }
 
         case Setup::EditorPage:
+        {
             return page_editor;
+        }
 
         case Setup::ImageQualityPage:
+        {
             return page_imagequalitysorter;
+        }
 
         case Setup::ICCPage:
+        {
             return page_icc;
+        }
 
         case Setup::CameraPage:
+        {
             return page_camera;
+        }
 
         case Setup::PluginsPage:
+        {
             return page_plugins;
+        }
 
         case Setup::MiscellaneousPage:
+        {
             return page_misc;
+        }
 
         default:
+        {
             return nullptr;
+        }
     }
 }
 
